@@ -11,14 +11,10 @@ use warnings;
 use strict;
 
 package Audio::MPD::Types;
-our $VERSION = '1.093170';
-
-
+our $VERSION = '1.100430';
 # ABSTRACT: types used in the distribution
 
 use Moose::Util::TypeConstraints;
-use Sub::Exporter;
-use Sub::Exporter -setup => { exports => [ qw{ CONNTYPE } ] };
 
 enum CONNTYPE  => qw{ reuse once };
 
@@ -33,15 +29,15 @@ Audio::MPD::Types - types used in the distribution
 
 =head1 VERSION
 
-version 1.093170
+version 1.100430
 
 =head1 DESCRIPTION
 
 This module implements the specific types used by the distribution, and
-exports them. It is using L<Sub::Exporter> underneath, so you can use
-all the shenanigans to change the export names.
+exports them (exporting is done directly by
+L<Moose::Util::TypeConstraints>.
 
-Current types defined and exported:
+Current types defined:
 
 =over 4
 
@@ -64,4 +60,5 @@ the same terms as the Perl 5 programming language system itself.
 =cut
 
 
-__END__
\ No newline at end of file
+__END__
+
